--- loncom/interface/lonmeta.pm 2012/11/09 18:56:50 1.248
+++ loncom/interface/lonmeta.pm 2014/06/22 19:46:48 1.254
@@ -1,7 +1,7 @@
# The LearningOnline Network with CAPA
# Metadata display handler
#
-# $Id: lonmeta.pm,v 1.248 2012/11/09 18:56:50 bisitz Exp $
+# $Id: lonmeta.pm,v 1.254 2014/06/22 19:46:48 raeburn Exp $
#
# Copyright Michigan State University Board of Trustees
#
@@ -389,9 +389,9 @@ sub select_course {
&mt('You can choose to transfer data from the added fields to the "Notes" field if you are planning to change the course association.').'
'.
&Apache::loncommon::start_data_table().
&Apache::loncommon::start_data_table_header_row().
- '
Copy to notes? | '."\n".
- 'Field name | '."\n".
- 'Values | '."\n".
+ ''.&mt('Copy to notes?').' | '."\n".
+ ''.&mt('Field Name').' | '."\n".
+ ''.&mt('Values').' | '."\n".
&Apache::loncommon::end_data_table_header_row().
$transfernotes.
&Apache::loncommon::end_data_table().'
';
@@ -455,7 +455,7 @@ sub prettyprint {
}
# MIME
if ($type eq 'mime') {
- return '
'.
+ return '
'.
&Apache::loncommon::filedescription($value);
}
# Person
@@ -763,7 +763,7 @@ sub pageheader {
sub handler {
my $r=shift;
&Apache::loncommon::get_unprocessed_cgi($ENV{'QUERY_STRING'},
- ['currentpath','changecourse']);
+ ['currentpath','changecourse','modal']);
my $uri=$r->uri;
#
# Set document type
@@ -778,7 +778,7 @@ sub handler {
if ($env{'request.state'} eq 'construct') {
&Apache::lonhtmlcommon::add_breadcrumb({
- 'text' => 'Construction Space',
+ 'text' => 'Authoring Space',
'href' => &Apache::loncommon::authorspace($uri),
});
}
@@ -829,7 +829,7 @@ sub handler {
$r->print(&pageheader());
&present_editable_metadata($r,$uri,'groups');
} elsif ($uri=~m|^/priv|) {
- # Construction space
+ # Authoring space
&Apache::lonhtmlcommon::add_breadcrumb({
'text' => 'Edit Metadata',
'href' => '',
@@ -854,7 +854,21 @@ sub handler {
'only_body' => 1,})
.''.&mt('Metadata').'
'
);
+ if ($env{'form.modal'}) {
+ my $width = 500;
+ my $height = 400;
+ my $machine = &Apache::lonnet::absolute_url();
+ $r->print(&Apache::loncommon::nicescroll_javascript('metadatawrapper',
+ {cursorcolor => '#00F',
+ railalign => 'right',
+ railoffset => '{top:5,left:40}'},
+ undef,1,$machine.$uri));
+ $r->print('');
+ }
&present_uneditable_metadata($r,$uri);
+ if ($env{'form.modal'}) {
+ $r->print('
');
+ }
}
$r->print(&Apache::loncommon::end_page());
return OK;
@@ -872,7 +886,11 @@ sub report_bombs {
# Set document type
$uri =~ s:/adm/bombs/::;
$uri = &Apache::lonnet::declutter($uri);
- $r->print(''.&Apache::lonnet::clutter($uri).'
');
+ $r->print(
+ ''.&mt('Folder: [_1]',
+ ''.&Apache::lonnet::clutter($uri).'')
+ .'
'
+ );
my ($domain,$author)=($uri=~/^($match_domain)\/($match_username)\//);
if (!&Apache::lonnet::constructaccess('/priv/'.$domain.'/'.$author.'/')) {
$r->print(''.&mt('Not authorized').'
');
@@ -965,7 +983,7 @@ sub present_uneditable_metadata {
$currentversion :
&mt('information not available')).')';
} else {
- $versiondisplay='Version: '.$currentversion;
+ $versiondisplay=&mt('Version: [_1]',$currentversion);
}
}
# crumbify displayed URL uri target prefix form
@@ -983,7 +1001,7 @@ sub present_uneditable_metadata {
my $table='';
my $title = $content{'title'};
if (! defined($title)) {
- $title = 'Untitled Resource';
+ $title = &mt('Untitled Resource');
}
my @fields;
if ($uploaded) {
@@ -1118,6 +1136,7 @@ sub print_dynamic_metadata {
if (exists($dynmeta{'stats'})) {
my $table=&Apache::loncommon::start_data_table()
.&Apache::loncommon::start_data_table_header_row()
+ .''.&mt('Domain').' | '
.''.&mt('Course').' | '
.''.&mt('Section(s)').' | '
.''.&mt('Num Students').' | '
@@ -1138,6 +1157,8 @@ sub print_dynamic_metadata {
next;
}
$table .= &Apache::loncommon::start_data_table_row();
+ $table .=
+ ''.$courseinfo{'domain'}.' | ';
$table .=
''.$courseinfo{'description'}.' | ';
$table .=
@@ -1174,7 +1195,6 @@ sub print_dynamic_metadata {
&mt('No Assessment Statistical Data is available for this resource').
'');
}
-
#
# Evaluation Data
$r->print(''.&mt('Evaluation Data').'
');
@@ -1289,7 +1309,7 @@ sub print_dynamic_metadata {
#####################################################
sub present_editable_metadata {
my ($r,$uri,$file_type) = @_;
# Construction Space Call
# Header
my $disuri=$uri;
my $fn=&Apache::lonnet::filelocation('',$uri);
@@ -1306,7 +1326,12 @@ sub present_editable_metadata {
my $bombs=&Apache::lonmsg::retrieve_author_res_msg($target);
if ($bombs) {
# Display Bombs, not Metadata
- $r->print("$disuri
");
+ $r->print(
+ ''.&mt('Error Messages').'
'
+ .''.&mt('Folder: [_1]',
+ ''.$disuri.'')
+ .'
'
+ );
my $showbuttons=1;
my $message='';
my $rc='';
@@ -1367,7 +1392,7 @@ sub present_editable_metadata {
# Display Metadata, not Bombs
my $displayfile =
&mt('Metadata for [_1]'
- ,'');
+ ,''.$disuri.'');
if ($disuri=~/\/default$/) {
my $dir=$disuri;
$dir=~s/default$//;
@@ -1403,7 +1428,7 @@ sub present_editable_metadata {
}
}
$r->print(<$displayfile
+$displayfile
@@ -1289,7 +1309,7 @@ sub print_dynamic_metadata {
sub present_editable_metadata {
my ($r,$uri,$file_type) = @_;
- # Construction Space Call
+ # Authoring Space Call
# Header
my $disuri=$uri;